# Generated by Django 4.0.10 on 2023-05-15 09:17

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='General',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('view_corp', 'Can view linked character of members of their corporation.'), ('view_alliance', 'Can view linked character of members of their alliance.'), ('view_state', 'Can view linked character of members of their auth state.')),
                'managed': False,
                'default_permissions': (),
            },
        ),
    ]
